coherence.extern.db_row (module) — Cohen3 0.8.0 documentation

# coherence.extern.db_row (module)

`get_rows`(cursor, sql)

  Return a list of ResultRow objects from an SQL query.

`getdict`(results, description)

  Return the list of DBRows in results with a given description.

class `DBRow`(row, fields)

  Bases: `object`

  A single row in a result set.

  Each DBRow has a dictionary-style and list-style interface.

  Called by ResultSet function. Don’t call directly

  `__init__`(row, fields)

    Called by ResultSet function. Don’t call directly

  `set_extra_attr`(attr, value)
  `keys`()

    Return the field names

  `keymappings`()

    Return a dictionary of the keys and their indices in the row

  `has_key`(key)

    Return whether the given key is valid

  `as_dict`()